from typing import Any

class Parser:
    environment: Any
    stream: Any
    name: Any
    filename: Any
    closed: bool
    extensions: Any
    def __init__(
        self, environment, source, name: Any | None = ..., filename: Any | None = ..., state: Any | None = ...
    ) -> None: ...
    def fail(self, msg, lineno: Any | None = ..., exc: Any = ...): ...
    def fail_unknown_tag(self, name, lineno: Any | None = ...): ...
    def fail_eof(self, end_tokens: Any | None = ..., lineno: Any | None = ...): ...
    def is_tuple_end(self, extra_end_rules: Any | None = ...): ...
    def free_identifier(self, lineno: Any | None = ...): ...
    def parse_statement(self): ...
    def parse_statements(self, end_tokens, drop_needle: bool = ...): ...
    def parse_set(self): ...
    def parse_for(self): ...
    def parse_if(self): ...
    def parse_block(self): ...
    def parse_extends(self): ...
    def parse_import_context(self, node, default): ...
    def parse_include(self): ...
    def parse_import(self): ...
    def parse_from(self): ...
    def parse_signature(self, node): ...
    def parse_call_block(self): ...
    def parse_filter_block(self): ...
    def parse_macro(self): ...
    def parse_print(self): ...
    def parse_assign_target(self, with_tuple: bool = ..., name_only: bool = ..., extra_end_rules: Any | None = ...): ...
    def parse_expression(self, with_condexpr: bool = ...): ...
    def parse_condexpr(self): ...
    def parse_or(self): ...
    def parse_and(self): ...
    def parse_not(self): ...
    def parse_compare(self): ...
    def parse_add(self): ...
    def parse_sub(self): ...
    def parse_concat(self): ...
    def parse_mul(self): ...
    def parse_div(self): ...
    def parse_floordiv(self): ...
    def parse_mod(self): ...
    def parse_pow(self): ...
    def parse_unary(self, with_filter: bool = ...): ...
    def parse_primary(self): ...
    def parse_tuple(
        self,
        simplified: bool = ...,
        with_condexpr: bool = ...,
        extra_end_rules: Any | None = ...,
        explicit_parentheses: bool = ...,
    ): ...
    def parse_list(self): ...
    def parse_dict(self): ...
    def parse_postfix(self, node): ...
    def parse_filter_expr(self, node): ...
    def parse_subscript(self, node): ...
    def parse_subscribed(self): ...
    def parse_call(self, node): ...
    def parse_filter(self, node, start_inline: bool = ...): ...
    def parse_test(self, node): ...
    def subparse(self, end_tokens: Any | None = ...): ...
    def parse(self): ...



from setuptools import setup

name = "types-Jinja2"
description = "Typing stubs for Jinja2"
long_description = '''
## Typing stubs for Jinja2

This is a PEP 561 type stub package for the `Jinja2` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `Jinja2`. The source for this package can be found at
https://github.com/python/typeshed/tree/master/stubs/Jinja2. All fixes for
types and metadata should be contributed there.

*Note:* The `Jinja2` package includes type annotations or type stubs
since version 3.0. Please uninstall the `types-Jinja2`
package if you use this or a newer version.


See https://github.com/python/typeshed/blob/master/README.md for more details.
This package was generated from typeshed commit `9f869723509ac027bae6b6f567b921d6a229e8ec`.
'''.lstrip()

setup(name=name,
      version="2.11.7",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      install_requires=['types-MarkupSafe'],
      packages=['jinja2-stubs'],
      package_data={'jinja2-stubs': ['__init__.pyi', '_compat.pyi', '_stringdefs.pyi', 'bccache.pyi', 'compiler.pyi', 'constants.pyi', 'debug.pyi', 'defaults.pyi', 'environment.pyi', 'exceptions.pyi', 'ext.pyi', 'filters.pyi', 'lexer.pyi', 'loaders.pyi', 'meta.pyi', 'nodes.pyi', 'optimizer.pyi', 'parser.pyi', 'runtime.pyi', 'sandbox.pyi', 'tests.pyi', 'utils.pyi', 'visitor.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Typing :: Typed",
      ]
)
